@@ -6,7 +6,7 @@ extern crate rand;
 
 use criterion::{AxisScale, Criterion, ParameterizedBenchmark, PlotConfiguration};
 use delaunator::{triangulate, Point};
-use rand::{Rng, SeedableRng, rngs::StdRng};
+use rand::{rngs::StdRng, Rng, SeedableRng};
 use std::iter::repeat_with;
 
 const COUNTS: &[usize] = &[100, 1000, 10_000, 100_000];
