@@ -1,6 +1,3 @@
-extern crate delaunator;
-extern crate rand;
-
 use std::iter::repeat_with;
 
 const N: usize = 1_000_000;
@@ -12,7 +9,7 @@ fn main() {
         .collect();
 
     let now = std::time::Instant::now();
-    let result = delaunator::triangulate(&points).expect("No triangulation exists for this input.");
+    let result = delaunator::triangulate(&points);
     let elapsed = now.elapsed();
 
     println!(
